EXPORTS
	??0TApaAppEntry@@QAE@XZ @ 1 NONAME ; TApaAppEntry::TApaAppEntry(void)
	??1CApaAppData@@UAE@XZ @ 2 NONAME ; CApaAppData::~CApaAppData(void)
	??1CApaAppList@@UAE@XZ @ 3 NONAME ; CApaAppList::~CApaAppList(void)
	??1CAppSidChecker@@UAE@XZ @ 4 NONAME ; CAppSidChecker::~CAppSidChecker(void)
	?AddForcedRegistrationL@CApaAppList@@QAEXABVTDesC16@@@Z @ 5 NONAME ABSENT; void CApaAppList::AddForcedRegistrationL(class TDesC16 const &)
	?AppDataByFileName@CApaAppList@@QBEPAVCApaAppData@@ABVTDesC16@@@Z @ 6 NONAME ; class CApaAppData * CApaAppList::AppDataByFileName(class TDesC16 const &) const
	?AppDataByUid@CApaAppList@@QBEPAVCApaAppData@@VTUid@@@Z @ 7 NONAME ; class CApaAppData * CApaAppList::AppDataByUid(class TUid) const
	?AppEntry@CApaAppData@@QBE?AVTApaAppEntry@@XZ @ 8 NONAME ; class TApaAppEntry CApaAppData::AppEntry(void) const
	?AppScanInProgress@CApaAppList@@QBEHXZ @ 9 NONAME ; int CApaAppList::AppScanInProgress(void) const
	?ApplicationLanguage@CApaAppData@@QBE?AW4TLanguage@@XZ @ 10 NONAME ; enum TLanguage CApaAppData::ApplicationLanguage(void) const
	?CanUseScreenMode@CApaAppData@@QAEHH@Z @ 11 NONAME ; int CApaAppData::CanUseScreenMode(int)
	?Capability@CApaAppData@@QBEXAAVTDes8@@@Z @ 12 NONAME ; void CApaAppData::Capability(class TDes8 &) const
	?Count@CApaAppList@@QBEHXZ @ 13 NONAME ; int CApaAppList::Count(void) const
	?DataType@CApaAppData@@QBEJABVTDataType@@@Z @ 14 NONAME ; long CApaAppData::DataType(class TDataType const &) const
	?DefaultScreenNumber@CApaAppData@@QBEIXZ @ 15 NONAME ; unsigned int CApaAppData::DefaultScreenNumber(void) const
	?DriveList@CApaAppRegFinder@@QBE?AV?$TArray@$$CBVTDriveUnitInfo@@@@XZ @ 16 NONAME ABSENT ; class TArray<class TDriveUnitInfo const > CApaAppRegFinder::DriveList(void) const
	?FindAllAppsL@CApaAppRegFinder@@QAEXW4TScanScope@1@@Z @ 17 NONAME ABSENT ; void CApaAppRegFinder::FindAllAppsL(enum CApaAppRegFinder::TScanScope)
	?FindAndAddSpecificAppL@CApaAppList@@QAEPAVCApaAppData@@PAVCApaAppRegFinder@@VTUid@@@Z @ 18 NONAME ABSENT ; class CApaAppData * CApaAppList::FindAndAddSpecificAppL(class CApaAppRegFinder *, class TUid)
	?FirstApp@CApaAppList@@QBEPAVCApaAppData@@H@Z @ 19 NONAME ; class CApaAppData * CApaAppList::FirstApp(int) const
	?FirstApp@CApaAppList@@QBEPAVCApaAppData@@XZ @ 20 NONAME ; class CApaAppData * CApaAppList::FirstApp(void) const
	?GetIconInfo@CApaAppData@@QBEXAAH0@Z @ 21 NONAME ; void CApaAppData::GetIconInfo(int &, int &) const
	?Icon@CApaAppData@@QBEPAVCApaMaskedBitmap@@H@Z @ 22 NONAME ; class CApaMaskedBitmap * CApaAppData::Icon(int) const
	?Icon@CApaAppData@@QBEPAVCApaMaskedBitmap@@VTSize@@@Z @ 23 NONAME ; class CApaMaskedBitmap * CApaAppData::Icon(class TSize) const
	?Icon@CApaAppViewData@@QBEPAVCApaMaskedBitmap@@ABVTSize@@@Z @ 24 NONAME ; class CApaMaskedBitmap * CApaAppViewData::Icon(class TSize const &) const
	?IconFileName@CApaAppData@@QBE?AVTPtrC16@@XZ @ 25 NONAME ; class TPtrC16 CApaAppData::IconFileName(void) const
	?IconFileName@CApaAppViewData@@QBE?AVTPtrC16@@XZ @ 26 NONAME ; class TPtrC16 CApaAppViewData::IconFileName(void) const
	?IconSizesL@CApaAppData@@QBEPAV?$CArrayFixFlat@VTSize@@@@XZ @ 27 NONAME ; class CArrayFixFlat<class TSize> * CApaAppData::IconSizesL(void) const
	?IconSizesL@CApaAppViewData@@QBEPAV?$CArrayFixFlat@VTSize@@@@XZ @ 28 NONAME ; class CArrayFixFlat<class TSize> * CApaAppViewData::IconSizesL(void) const
	?ImplementsService@CApaAppData@@QBEHVTUid@@@Z @ 29 NONAME ; int CApaAppData::ImplementsService(class TUid) const
	?InitListL@CApaAppList@@QAEXPAVMApaAppListObserver@@@Z @ 30 NONAME ; void CApaAppList::InitListL(class MApaAppListObserver *)
	?IsFirstScanComplete@CApaAppList@@QBEHXZ @ 31 NONAME ; int CApaAppList::IsFirstScanComplete(void) const
	?IsIdleUpdateComplete@CApaAppList@@QBEHXZ @ 32 NONAME ; int CApaAppList::IsIdleUpdateComplete(void) const
	?IsLanguageChangePending@CApaAppList@@QBEHXZ @ 33 NONAME ; int CApaAppList::IsLanguageChangePending(void) const
	?IsPending@CApaAppData@@QBEHXZ @ 34 NONAME ABSENT ; int CApaAppData::IsPending(void) const
	?LocalisableResourceFileName@CApaAppData@@QBE?AVTPtrC16@@XZ @ 35 NONAME ABSENT ; class TPtrC16 CApaAppData::LocalisableResourceFileName(void) const
	?NewL@CApaAppData@@SAPAV1@ABVTApaAppEntry@@AAVRFs@@@Z @ 36 NONAME ABSENT ; class CApaAppData * CApaAppData::NewL(class TApaAppEntry const &, class RFs &)
	?NewL@CApaAppList@@SAPAV1@AAVRFs@@HH@Z @ 37 NONAME ; class CApaAppList * CApaAppList::NewL(class RFs &, int, int)
	?NewL@CApaAppRegFinder@@SAPAV1@ABVRFs@@@Z @ 38 NONAME ABSENT ; class CApaAppRegFinder * CApaAppRegFinder::NewL(class RFs const &)
	?NewLC@CApaAppRegFinder@@SAPAV1@ABVRFs@@@Z @ 39 NONAME ABSENT ; class CApaAppRegFinder * CApaAppRegFinder::NewLC(class RFs const &)
	?NextApp@CApaAppList@@QBEPAVCApaAppData@@PBV2@@Z @ 40 NONAME ; class CApaAppData * CApaAppList::NextApp(class CApaAppData const *) const
	?NextApp@CApaAppList@@QBEPAVCApaAppData@@PBV2@H@Z @ 41 NONAME ; class CApaAppData * CApaAppList::NextApp(class CApaAppData const *, int) const
	?NextL@CApaAppRegFinder@@QAEHAAVTApaAppEntry@@ABVCDesC16Array@@@Z @ 42 NONAME ABSENT ; int CApaAppRegFinder::NextL(class TApaAppEntry &, class CDesC16Array const &)
	?NonMbmIconFile@CApaAppData@@QBEHXZ @ 43 NONAME ; int CApaAppData::NonMbmIconFile(void) const
	?NonMbmIconFile@CApaAppViewData@@QBEHXZ @ 44 NONAME ; int CApaAppViewData::NonMbmIconFile(void) const
	?NonNativeApplicationType@CApaAppData@@QBE?AVTUid@@XZ @ 45 NONAME ; class TUid CApaAppData::NonNativeApplicationType(void) const
	?OpaqueData@CApaAppData@@QBE?AVTPtrC8@@XZ @ 46 NONAME ; class TPtrC8 CApaAppData::OpaqueData(void) const
	?OwnedFiles@CApaAppData@@QBEPAVCDesC16Array@@XZ @ 47 NONAME ; class CDesC16Array * CApaAppData::OwnedFiles(void) const
	?PreferredDataHandlerL@CApaAppList@@QBE?AVTUid@@ABVTDataType@@@Z @ 48 NONAME ; class TUid CApaAppList::PreferredDataHandlerL(class TDataType const &) const
	?PreferredDataHandlerL@CApaAppList@@QBE?AVTUid@@ABVTDataType@@PBV2@AAH@Z @ 49 NONAME ; class TUid CApaAppList::PreferredDataHandlerL(class TDataType const &, class TUid const *, int &) const
	?PurgeL@CApaAppList@@QAEXXZ @ 50 NONAME ABSENT ; void CApaAppList::PurgeL(void)
	?RegistrationFileName@CApaAppData@@QBE?AVTPtrC16@@XZ @ 51 NONAME ABSENT ; class TPtrC16 CApaAppData::RegistrationFileName(void) const
	?RegistrationFileUsed@CApaAppData@@QBEHXZ @ 52 NONAME ABSENT ; int CApaAppData::RegistrationFileUsed(void) const
	?ResetForcedRegistrations@CApaAppList@@QAEXXZ @ 53 NONAME ABSENT; void CApaAppList::ResetForcedRegistrations(void)
	?RestartScanL@CApaAppList@@QAEXXZ @ 54 NONAME ABSENT ; void CApaAppList::RestartScanL(void)
	?ScreenMode@CApaAppViewData@@QBEHXZ @ 55 NONAME ; int CApaAppViewData::ScreenMode(void) const
	?Self@CApaAppList@@SAPAV1@XZ @ 56 NONAME ; class CApaAppList * CApaAppList::Self(void)
	?ServiceArrayBufferL@CApaAppList@@QBEPAVCBufFlat@@VTUid@@@Z @ 57 NONAME ; class CBufFlat * CApaAppList::ServiceArrayBufferL(class TUid) const
	?ServiceImplArrayBufferL@CApaAppList@@QBEPAVCBufFlat@@VTUid@@@Z @ 58 NONAME ; class CBufFlat * CApaAppList::ServiceImplArrayBufferL(class TUid) const
	?ServiceImplArrayBufferL@CApaAppList@@QBEPAVCBufFlat@@VTUid@@ABVTDataType@@@Z @ 59 NONAME ; class CBufFlat * CApaAppList::ServiceImplArrayBufferL(class TUid, class TDataType const &) const
	?ServiceOpaqueDataBufferL@CApaAppList@@QBEPAVCBufFlat@@VTUid@@0@Z @ 60 NONAME ; class CBufFlat * CApaAppList::ServiceOpaqueDataBufferL(class TUid, class TUid) const
	?ServiceUidBufferL@CApaAppList@@QBEPAVCBufFlat@@VTUid@@@Z @ 61 NONAME ; class CBufFlat * CApaAppList::ServiceUidBufferL(class TUid) const
	?SetRescanCallBackL@CAppSidChecker@@UAEXABVTCallBack@@@Z @ 62 NONAME ; void CAppSidChecker::SetRescanCallBackL(class TCallBack const &)
	?SetShortCaptionL@CApaAppData@@QAEXABVTDesC16@@@Z @ 63 NONAME ; void CApaAppData::SetShortCaptionL(class TDesC16 const &)
	?StartIdleUpdateL@CApaAppList@@QAEXPAVMApaAppListObserver@@@Z @ 64 NONAME ; void CApaAppList::StartIdleUpdateL(class MApaAppListObserver *)
	?StartIdleUpdateL@CApaAppList@@QAEXXZ @ 65 NONAME ; void CApaAppList::StartIdleUpdateL(void)
	?StopScan@CApaAppList@@QAEXH@Z @ 66 NONAME ABSENT ; void CApaAppList::StopScan(int)
	?Uid@CApaAppViewData@@QBE?AVTUid@@XZ @ 67 NONAME ; class TUid CApaAppViewData::Uid(void) const
	?Views@CApaAppData@@QBEPAV?$CArrayPtrFlat@VCApaAppViewData@@@@XZ @ 68 NONAME ; class CArrayPtrFlat<class CApaAppViewData> * CApaAppData::Views(void) const
	?reserved1@CAppSidChecker@@EAEXXZ @ 69 NONAME ; void CAppSidChecker::reserved1(void)
	?reserved2@CAppSidChecker@@EAEXXZ @ 70 NONAME ; void CAppSidChecker::reserved2(void)
	?reserved3@CAppSidChecker@@EAEXXZ @ 71 NONAME ; void CAppSidChecker::reserved3(void)
	?AddCustomAppInfoInListL@CApaAppList@@QAEXVTUid@@W4TLanguage@@ABVTDesC16@@@Z @ 72 NONAME ; void CApaAppList::AddCustomAppInfoInListL(class TUid, enum TLanguage, class TDesC16 const &)
	?UpdateAppListByShortCaptionL@CApaAppList@@QAEXXZ @ 73 NONAME ; void CApaAppList::UpdateAppListByShortCaptionL(void)
	?SetCaptionL@CApaAppData@@QAEXABVTDesC16@@@Z @ 74 NONAME ; void CApaAppData::SetCaptionL(class TDesC16 const &)
	?UpdateAppListByIconCaptionOverridesL@CApaAppList@@QAEXXZ @ 75 NONAME ; void CApaAppList::UpdateAppListByIconCaptionOverridesL(void)
	?SetIconsL@CApaAppData@@QAEXABVTDesC16@@H@Z @ 76 NONAME ; void CApaAppData::SetIconsL(class TDesC16 const &, int)
	?AppListUpdatePending@CApaAppList@@QAEHXZ @ 77 NONAME ABSENT ; int CApaAppList::AppListUpdatePending(void)
	?UninstalledAppArray@CApaAppList@@QAEPAV?$CArrayFixFlat@VTUid@@@@XZ @ 78 NONAME ; class CArrayFixFlat<class TUid> * CApaAppList::UninstalledAppArray(void)
	?FindAndAddSpecificAppL@CApaAppList@@QAEPAVCApaAppData@@VTUid@@@Z @ 79 NONAME ; class CApaAppData * CApaAppList::FindAndAddSpecificAppL(class TUid)
	?NewL@CApaAppData@@SAPAV1@ABVCApplicationRegistrationData@Usif@@AAVRFs@@ABVRSoftwareComponentRegistry@3@@Z @ 80 NONAME ; class CApaAppData * CApaAppData::NewL(class Usif::CApplicationRegistrationData const &, class RFs &, class Usif::RSoftwareComponentRegistry const &)
	?UpdateApplistL@CApaAppList@@QAEXPAVMApaAppListObserver@@PAV?$RArray@VTApaAppUpdateInfo@@@@VTUid@@@Z @ 81 NONAME ; void CApaAppList::UpdateApplistL(class MApaAppListObserver *, class RArray<class TApaAppUpdateInfo> *, class TUid)
	?InitializeApplistL@CApaAppList@@QAEXPAVMApaAppListObserver@@@Z @ 82 NONAME ; void CApaAppList::InitializeApplistL(class MApaAppListObserver *)
	?UpdateApplistByForceRegAppsL@CApaAppList@@QAEXAAV?$RPointerArray@VCApplicationRegistrationData@Usif@@@@@Z @ 83 NONAME ; void CApaAppList::UpdateApplistByForceRegAppsL(class RPointerArray<class Usif::CApplicationRegistrationData> &)
	?UpdatedAppsInfo@CApaAppList@@QAEPAV?$CArrayFixFlat@VTApaAppUpdateInfo@@@@XZ @ 84 NONAME ; class CArrayFixFlat<class TApaAppUpdateInfo> * CApaAppList::UpdatedAppsInfo(void)
	?IsLangChangePending@CApaAppData@@QAEHXZ @ 85 NONAME ; int CApaAppData::IsLangChangePending(void)

